OC.L10N.register(
    "files",
    {
    "Added to favorites" : "Añadido a favoritos",
    "Removed from favorites" : "Quitado de favoritos",
    "You added {file} to your favorites" : "Has añadido {file} a tus favoritos",
    "You removed {file} from your favorites" : "Has quitado {file} de tus favoritos",
    "Favorites" : "Favoritos",
    "File changes" : "Cambios del archivo",
    "Created by {user}" : "Creado por {user}",
    "Changed by {user}" : "Modificado por {user}",
    "Deleted by {user}" : "Borrado por {user}",
    "Restored by {user}" : "Restaurado por {user}",
    "Renamed by {user}" : "Renombrado por {user}",
    "Moved by {user}" : "Movido por {user}",
    "\"remote account\"" : "\"cuenta remota\"",
    "You created {file}" : "Ha creado {file}",
    "You created an encrypted file in {file}" : "Has creado un archivo cifrado en {file}",
    "{user} created {file}" : "{user} ha creado {file}",
    "{user} created an encrypted file in {file}" : "{user} ha creado un archivo cifrado en {file}",
    "{file} was created in a public folder" : "{file} se ha creado en una carpeta pública",
    "You changed {file}" : "Has cambiado {file}",
    "You changed an encrypted file in {file}" : "Has modificado un archivo cifrado en {file}",
    "{user} changed {file}" : "{user} ha cambiado {file}",
    "{user} changed an encrypted file in {file}" : "{user} ha modificado un archivo cifrado en {file}",
    "You deleted {file}" : "Has borrado {file}",
    "You deleted an encrypted file in {file}" : "Has borrado un archivo cifrado en {file}",
    "{user} deleted {file}" : "{user} eliminó {file}",
    "{user} deleted an encrypted file in {file}" : "{user} ha borrado un archivo cifrado en {file}",
    "You restored {file}" : "Has restaurado {file}",
    "{user} restored {file}" : "{user} restauró {file}",
    "You renamed {oldfile} (hidden) to {newfile} (hidden)" : "Has renombrado {oldfile} (oculto) a {newfile} (oculto)",
    "You renamed {oldfile} (hidden) to {newfile}" : "Has renombrado {oldfile} (oculto) a {newfile}",
    "You renamed {oldfile} to {newfile} (hidden)" : "Has renombrado {oldfile} a {newfile} (oculto)",
    "You renamed {oldfile} to {newfile}" : "Has renombrado {oldfile} a {newfile}",
    "{user} renamed {oldfile} (hidden) to {newfile} (hidden)" : "{user} renombró {oldfile} (oculto) a {newfile} (oculto)",
    "{user} renamed {oldfile} (hidden) to {newfile}" : "{user} renombró {oldfile} (oculto) a {newfile}",
    "{user} renamed {oldfile} to {newfile} (hidden)" : "{user} renombró {oldfile} a {newfile} (oculto)",
    "{user} renamed {oldfile} to {newfile}" : "{user} ha renombrado {oldfile} a {newfile}",
    "You moved {oldfile} to {newfile}" : "Has movido {oldfile} a {newfile}",
    "{user} moved {oldfile} to {newfile}" : "{user} movió {oldfile} a {newfile}",
    "A file has been added to or removed from your <strong>favorites</strong>" : "Un archivo se ha añadido o borrado de tus <strong>favoritos</strong>",
    "Files" : "Archivos",
    "A file or folder has been <strong>changed</strong>" : "Se ha <strong>modificado</strong> un archivo o carpeta",
    "A favorite file or folder has been <strong>changed</strong>" : "Un archivo favorito o carpeta se ha <strong>cambiado</strong>",
    "Failed to authorize" : "Fallo al autorizar",
    "Invalid folder path" : "Ruta de carpeta inválida",
    "Folder not found" : "Carpeta no encontrada",
    "The file cannot be found" : "El archivo no se puede encontrar",
    "The destination path does not exist: %1$s" : "La ruta de destino no existe: %1$s",
    "You do not have permission to create a file at the specified location" : "No tiene permiso para crear un archivo en la ubicación especificada",
    "The file could not be converted." : "No se ha podido convertir el archivo.",
    "Could not get relative path to converted file" : "No se ha podido obtener la ruta relativa al archivo convertido",
    "Limit must be a positive integer." : "El límite debe ser un entero positivo.",
    "The replacement character may only be a single character." : "El carácter de reemplazo solo puede ser un solo carácter.",
    "Filename sanitization already started." : "El saneamiento de nombres de archivo ya ha comenzado.",
    "No filename sanitization in progress." : "No hay saneamiento de nombres de archivo en progreso.",
    "Favorite files" : "Archivos favoritos",
    "No favorites" : "No hay favoritos",
    "More favorites" : "Más favoritos",
    "Accept" : "Aceptar",
    "Reject" : "Rechazar",
    "Incoming ownership transfer from {user}" : "Ha llegado una transferencia de propiedad de {user}",
    "Do you want to accept {path}?\n\nNote: The transfer process after accepting may take up to 1 hour." : "¿Deseas aceptar {path}?\n\nNota: El proceso de transferencia tras aceptar podría tardar hasta 1 hora.",
    "Ownership transfer denied" : "Se denegó la transferencia de propiedad",
    "Your ownership transfer of {path} was denied by {user}." : "Su transferencia de propiedad de {path} fue denegada por {user}.",
    "Ownership transfer failed" : "Fallo al transferir la propiedad",
    "Your ownership transfer of {path} to {user} failed." : "Ha fallado tu transferencia de propiedad de {path} a {user}.",
    "The ownership transfer of {path} from {user} failed." : "Ha fallado la transferencia de propiedad de {path} desde {user}.",
    "Ownership transfer done" : "Transferencia de propiedad realizada",
    "Your ownership transfer of {path} to {user} has completed." : "Se ha completado su transferencia de propiedad de {path} a {user}.",
    "The ownership transfer of {path} from {user} has completed." : "Se ha completado la transferencia de propiedad de {path} a {user}.",
    "in %s" : "en %s",
    "Transferred from %1$s on %2$s" : "Se transfirió desde %1$s en %2$s",
    "File Management" : "Gestión de archivos",
    "Home" : "Inicio",
    "Target folder does not exist any more" : "La carpeta destino ya no existe",
    "Reload current directory" : "Recargar carpeta actual",
    "Go to the \"{dir}\" directory" : "Ir a la carpeta \"{dir}\"",
    "Current directory path" : "Dirección de la carpeta actual",
    "Share" : "Compartir",
    "Reload content" : "Recargar contenido",
    "Your have used your space quota and cannot upload files anymore" : "Ha utilizado su cuota de espacio y ya no puede subir más archivos",
    "You do not have permission to upload or create files here." : "No tiene permiso para subir o crear archivos aquí",
    "Drag and drop files here to upload" : "Arrastre y suelte archivos aquí para subirlos",
    "Favorite" : "Favorito",
    "Back" : "Atrás",
    "Toggle selection for file \"{displayName}\"" : "Alternar selección para archivo \"{displayName}\"",
    "Toggle selection for folder \"{displayName}\"" : "Alternar selección para la carpeta \"{displayName}\"",
    "File is loading" : "El archivo se está cargando",
    "Folder is loading" : "La carpeta se está cargando",
    "Filename" : "Nombre de archivo",
    "Folder name" : "Nombre de la carpeta",
    "This node is unavailable" : "Este nodo no está disponible",
    "Another entry with the same name already exists." : "Ya existe otra entrada con el mismo nombre.",
    "Invalid filename." : "Nombre de archivo inválido.",
    "Rename file" : "Renombrar archivo",
    "Folder" : "Carpeta",
    "Unknown file type" : "Tipo de archivo desconocido",
    "{ext} image" : "imagen {ext}",
    "{ext} video" : "vídeo {ext}",
    "{ext} audio" : "audio {ext}",
    "{ext} text" : "texto {ext}",
    "Pending" : "Pendiente",
    "Unknown date" : "Fecha desconocida",
    "Active filters" : "Filtros activos",
    "Remove filter" : "Quitar filtro",
    "Today" : "Hoy",
    "Last 7 days" : "Últimos 7 días",
    "Last 30 days" : "Últimos 30 días",
    "This year ({year})" : "Este año ({year})",
    "Last year ({year})" : "El año pasado ({year})",
    "Custom range" : "Rango personalizado",
    "Custom date range" : "Rango de fechas personalizado",
    "Search everywhere" : "Buscar en todas partes",
    "Documents" : "Documentos",
    "Spreadsheets" : "Hojas de cálculo",
    "Presentations" : "Presentaciones",
    "PDFs" : "PDFs",
    "Folders" : "Carpetas",
    "Audio" : "Audio",
    "Images" : "Imágenes",
    "Videos" : "Vídeos",
    "Filters" : "Filtros",
    "Back to filters" : "Volver a filtros",
    "Appearance" : "Apariencia",
    "Show hidden files" : "Mostrar archivos ocultos",
    "Show file type column" : "Mostrar la columna de tipo de archivo",
    "Show file extensions" : "Mostrar extensiones de archivos",
    "Crop image previews" : "Recortar la previsualización de las imágenes",
    "General" : "General",
    "Sort favorites first" : "Ordenar los favoritos primero",
    "Sort folders before files" : "Ordenar carpetas antes que archivos",
    "Enable folder tree view" : "Habilitar la vista del árbol de carpetas",
    "Default view" : "Vista predeterminada",
    "All files" : "Todos los archivos",
    "Personal files" : "Archivos personales",
    "Additional settings" : "Ajustes adicionales",
    "Actions" : "Acciones",
    "File actions" : "Acciones de archivo",
    "Selection" : "Selección",
    "Select all files" : "Seleccionar todos los archivos",
    "Deselect all" : "Deseleccionar todos",
    "Select or deselect" : "Seleccionar o deseleccionar",
    "Select a range" : "Seleccionar rango",
    "Navigation" : "Navegación",
    "Go to parent folder" : "Ir a carpeta superior",
    "Go to file above" : "Ir al archivo anterior",
    "Go to file below" : "Ir al archivo siguiente",
    "Go left in grid" : "Desplazarse a la izquierda en la cuadrícula",
    "Go right in grid" : "Desplazarse a la derecha en la cuadrícula",
    "View" : "Vista",
    "Toggle grid view" : "Alternar vista de cuadrícula",
    "Show those shortcuts" : "Mostrar estos atajos",
    "Warnings" : "Advertencias",
    "Warn before changing a file extension" : "Advertir antes de cambiar la extensión de un archivo.",
    "Warn before deleting a file" : "Advertir antes de eliminar un archivo",
    "WebDAV URL" : "URL de WebDAV",
    "Create an app password" : "Crear nueva contraseña de app",
    "Required for WebDAV authentication because Two-Factor Authentication is enabled for this account." : "Necesario para la autenticación WebDAV porque la Autenticación de Dos Factores está habilitada para esta cuenta.",
    "How to access files using WebDAV" : "Como acceder a los archivos usando WebDAV",
    "Total rows summary" : "Resumen de filas totales",
    "Toggle selection for all files and folders" : "Seleccionar/deseleccionar todos los archivos y carpetas",
    "Name" : "Nombre",
    "File type" : "Tipo de archivo",
    "Size" : "Tamaño",
    "Modified" : "Modificado",
    "{displayName}: failed on some elements" : "{displayName}: falló en algunos elementos",
    "{displayName}: done" : "{displayName}: listo",
    "{displayName}: failed" : "{displayName}: falló",
    "(selected)" : "(seleccionado)",
    "List of files and folders." : "Lista de archivos y carpetas.",
    "You have used your space quota and cannot upload files anymore." : "Ha usado su cuota de almacenamiento y ya no puede subir más archivos.",
    "Column headers with buttons are sortable." : "Las columnas con botones en la cabecera son ordenables.",
    "This list is not fully rendered for performance reasons. The files will be rendered as you navigate through the list." : "Esta lista no se muestra completamente por motivos de rendimiento. Los archivos se mostrarán a medida que navega por la lista.",
    "File not found" : "No se ha encontrado el archivo",
    "_{count} selected_::_{count} selected_" : ["{count} seleccionado","{count} seleccionados","{count} seleccionados"],
    "Search everywhere …" : "Buscar en todas partes …",
    "Search here …" : "Buscar aquí …",
    "Search scope options" : "Opciones de alcance de la búsqueda",
    "Search here" : "Buscar aquí",
    "Owner" : "Dueño",
    "{usedQuotaByte} used" : "{usedQuotaByte} utilizados",
    "{used} of {quota} used" : "{used} usados de {quota}",
    "{relative}% used" : "{relative}% utilizado",
    "Could not refresh storage stats" : "No fue posible refrescar las estadísticas de almacenamiento",
    "Your storage is full, files can not be updated or synced anymore!" : "Su almacenamiento está lleno, ¡Ya no se pueden subir ni sincronizarse más archivos!",
    "Storage information" : "Información de almacenamiento",
    "Storage quota" : "Cuota de almacenamiento",
    "New folder" : "Nueva carpeta",
    "Create new folder" : "Crear carpeta nueva",
    "This name is already in use." : "Este nombre ya está en uso.",
    "Create" : "Crear",
    "Files starting with a dot are hidden by default" : "Los archivos que comienzan con un punto se ocultan de manera predeterminada",
    "Failed to start filename sanitization." : "Fallo al iniciar el saneamiento de nombres de archivo.",
    "Failed to refresh filename sanitization status." : "Fallo al refrescar el estado del saneamiento de nombres de archivo.",
    "Filename sanitization in progress." : "Saneamiento de nombres de archivo en progreso.",
    "Currently {processedUsers} of {totalUsers} accounts are already processed." : "Actualmente {processedUsers} de {totalUsers} cuentas ya han sido procesadas.",
    "Preparing …" : "Preparando …",
    "Refresh" : "Refrescar",
    "All files have been santized for Windows filename support." : "Todos los archivos se les ha saneado para el soporte de nombres de archivo Windows.",
    "Some files could not be sanitized, please check your logs." : "Algunos archivos no les pudo sanear el nombre de archivo, por favor, revise sus registros.",
    "Sanitization errors" : "Errores de saneamiento",
    "Not sanitized filenames" : "No se sanearon nombres de archivo",
    "Windows filename support has been enabled." : "El soporte a nombres de archivo windows se ha habilitado.",
    "While this blocks users from creating new files with unsupported filenames, existing files are not yet renamed and thus still may break sync on Windows." : "Mientras que esto bloquea a los usuarios de la posibilidad de crear archivos nuevos con nombres de archivo no soportados, los archivos existentes no han sido renombrados, y, por tanto, podrían afectar la sincronización en Windows.",
    "You can trigger a rename of files with invalid filenames, this will be done in the background and may take some time." : "Puede iniciar un renombrado de archivos con nombres de archivo inválidos, esto se hará en segundo plano y podría tomar algún tiempo.",
    "Please note that this may cause high workload on the sync clients." : "Por favor, tenga en cuenta que esto podría causar una alta carga de trabajo en los clientes de sincronización.",
    "Limit" : "Límite",
    "This allows to configure how many users should be processed in one background job run." : "Esto permite configurar cuantos usuarios deberían ser procesados en una corrida en segundo plano.",
    "Sanitize filenames" : "Sanear nombres de archivo",
    "(starting)" : "(iniciando)",
    "Fill template fields" : "Rellenar los campos de la plantilla",
    "Submitting fields …" : "Enviando campos …",
    "Submit" : "Enviar",
    "Choose a file or folder to transfer" : "Elegir un archivo o carpeta para transferir",
    "Transfer" : "Transferir",
    "Transfer {path} to {userid}" : "Transferir {path} a {userid}",
    "Invalid path selected" : "Ruta de archivo seleccionada no válida.",
    "Unknown error" : "Error desconocido",
    "Ownership transfer request sent" : "Enviada la solicitud de transferencia de propiedad",
    "Cannot transfer ownership of a file or folder you do not own" : "No puede transferir la propiedad de un archivo o carpeta de la cual no es propietario",
    "Transfer ownership of a file or folder" : "Transferir la propiedad de un archivo o carpeta",
    "Choose file or folder to transfer" : "Elegir archivo o carpeta para transferir",
    "Change" : "Cambiar",
    "New owner" : "Nuevo propietario",
    "Keep {old}" : "Conservar {old}",
    "Keep without extension" : "Conservar sin extensión",
    "Use {new}" : "Usar {new}",
    "Remove extension" : "Quitar la extensión",
    "Change file extension" : "Cambiar la extensión de archivo",
    "Changing the file extension from \"{old}\" to \"{new}\" may render the file unreadable." : "Cambiar la extensión de \"{old}\" a \"{new}\" podría hacer a el archivo ilegible.",
    "Removing the file extension \"{old}\" may render the file unreadable." : "Quitar la extensión \"{old}\" podría hacer a el archivo ilegible.",
    "Adding the file extension \"{new}\" may render the file unreadable." : "Añadir la extensión \"{new}\" podría hacer a el archivo ilegible.",
    "Do not show this dialog again." : "No mostrar este diálogo de nuevo.",
    "Rename file to hidden" : "Cambiar el nombre del archivo para ocultarlo",
    "Prefixing a filename with a dot may render the file hidden." : "Si antepones un punto al nombre de un archivo, éste podría quedar oculto.",
    "Are you sure you want to rename the file to \"{filename}\"?" : "¿Estás seguro que quieres cambiar el nombre del archivo a \"{filename}\"?",
    "Cancel" : "Cancelar",
    "Rename" : "Renombrar",
    "Select file or folder to link to" : "Selecciona archivo o carpeta a enlazar",
    "Choose {file}" : "Seleccionar {file}",
    "Files settings" : "Configuración de archivos",
    "Switch to list view" : "Cambiar a vista de lista",
    "Switch to grid view" : "Cambiar a vista de cuadrícula",
    "The file could not be found" : "El archivo no se pudo encontrar",
    "Upload was cancelled by user" : "La subida ha sido cancelada por el usuario",
    "Not enough free space" : "No hay espacio libre suficiente",
    "Operation is blocked by access control" : "Esta operación está bloqueada por el control de accesos",
    "Error during upload: {message}" : "Error durante la subida: {message}",
    "Error during upload, status code {status}" : "Error durante la subida, código de estado {status}",
    "Unknown error during upload" : "Error desconocido durante la subida",
    "File list is reloading" : "La lista de archivos se está recargando",
    "Loading current folder" : "Cargando carpeta actual",
    "Retry" : "Reintentar",
    "No files in here" : "Aquí no hay archivos",
    "Upload some content or sync with your devices!" : "¡Sube contenido o sincroniza tus dispositivos!",
    "Go back" : "Ir atrás",
    "Views" : "Vistas",
    "Loading …" : "Cargando …",
    "Your files" : "Sus archivos",
    "Open in files" : "Abrir en Archivos",
    "File cannot be accessed" : "No se ha podido acceder al archivo",
    "The file could not be found or you do not have permissions to view it. Ask the sender to share it." : "El archivo no fue encontrado o no tiene permisos para verlo. Solicite al remitente que lo comparta.",
    "No search results for “{query}”" : "No hay resultados para “{query}”",
    "Search for files" : "Buscar archivos",
    "Allow to restrict filenames to ensure files can be synced with all clients. By default all filenames valid on POSIX (e.g. Linux or macOS) are allowed." : "Permitir la restricción en nombres de archivo para asegurar que los archivos se puedan sincronizar con todos los clientes. Por defecto, se permiten todos los nombres de archivos válidos en POSIX (por ejemplo, Linux o macOS).",
    "After enabling the Windows compatible filenames, existing files cannot be modified anymore but can be renamed to valid new names by their owner." : "Una vez habilitados los nombres de archivo compatibles con Windows, los archivos existentes ya no se podrán modificar, pero su propietario podrá renombrarlos a otros nombres válidos de archivo.",
    "Failed to toggle Windows filename support" : "Fallo al conmutar el soporte a nombres de archivo Windows",
    "Files compatibility" : "Compatibilidad de archivos",
    "Enforce Windows compatibility" : "Forzar la compatibilidad con Windows",
    "This will block filenames not valid on Windows systems, like using reserved names or special characters. But this will not enforce compatibility of case sensitivity." : "Esto bloqueará los nombres de archivos inválidos en sistemas Windows, tales como usar nombres reservados o caracteres especiales. Pero no forzará la compatibilidad del uso de mayúsculas y minúsculas.",
    "Blank" : "Vacío",
    "Unable to create new file from template" : "No se ha podido crear un nuevo archivo desde la plantilla",
    "Pick a template for {name}" : "Elija una plantilla para {name}",
    "Create a new file with the selected template" : "Crear un nuevo archivo con la plantilla seleccionada",
    "Creating file" : "Creando el archivo",
    "Save as {displayName}" : "Guardar como {displayName}",
    "Save as …" : "Guardar como …",
    "Converting files …" : "Convirtiendo archivos …",
    "Failed to convert files: {message}" : "Fallo al convertir archivos: {message}",
    "All files failed to be converted" : "Todos los archivos han fallado al convertirse",
    "One file could not be converted: {message}" : "Un archivo no ha podido ser convertido: {message}",
    "_%n file could not be converted_::_%n files could not be converted_" : ["%n archivo no puede ser convertido","%n archivos no pueden ser convertidos","%n archivos no pueden ser convertidos"],
    "_%n file converted_::_%n files converted_" : ["%n archivo convertido","%n archivos convertidos","%n archivos convertidos"],
    "Files converted" : "Archivos convertidos",
    "Failed to convert files" : "Fallo al convertir archivos",
    "Converting file …" : "Convirtiendo archivo …",
    "File successfully converted" : "Archivo convertido exitosamente",
    "Failed to convert file: {message}" : "Fallo al convertir el archivo: {message}",
    "Failed to convert file" : "Fallo al convertir el archivo",
    "Delete" : "Eliminar",
    "Leave this share" : "Abandonar este recurso compartido",
    "Leave these shares" : "Abandonar estos recursos compartidos",
    "Disconnect storage" : "Desconectar almacenamiento",
    "Disconnect storages" : "Desconectar almacenamientos",
    "Delete permanently" : "Eliminar de forma permanente",
    "Delete and unshare" : "Eliminar y dejar de compartir",
    "Delete file" : "Eliminar archivo",
    "Delete files" : "Eliminar archivos",
    "Delete folder" : "Eliminar carpeta",
    "Delete folders" : "Eliminar carpetas",
    "_You are about to permanently delete {count} item_::_You are about to permanently delete {count} items_" : ["Está a punto de eliminar {count} elemento permanentemente","Está a punto de eliminar {count} elementos permanentemente.","Está a punto de eliminar {count} elementos permanentemente"],
    "_You are about to delete {count} item_::_You are about to delete {count} items_" : ["Está a punto de eliminar {count} elemento","Está a punto de eliminar {count} elementos","Está a punto de eliminar {count} elementos"],
    "Confirm deletion" : "Confirmar eliminación",
    "Download" : "Descargar",
    "The requested file is not available." : "El archivo solicitado no está disponible.",
    "The requested files are not available." : "Los archivos solicitados no están disponibles.",
    "Add to favorites" : "Añadir a favoritos",
    "Remove from favorites" : "Quitar de favoritos",
    "Add or remove favorite" : "Añadir o quitar favorito",
    "Move" : "Mover",
    "Copy" : "Copiar",
    "Move or copy" : "Mover o copiar",
    "Destination is not a folder" : "El destino no es una carpeta",
    "This file/folder is already in that directory" : "Este archivo/carpeta ya está en ese directorio",
    "You cannot move a file/folder onto itself or into a subfolder of itself" : "No puede mover un archivo/carpeta a sí mismo o a una sub-carpeta de sí mismo",
    "A file or folder with that name already exists in this folder" : "Un archivo o carpeta con ese nombre ya existe en esta carpeta",
    "The files are locked" : "Los archivos están bloqueados",
    "The file does not exist anymore" : "El archivo ya no existe",
    "Moving \"{source}\" to \"{destination}\" …" : "Moviendo \"{source}\" a \"{destination}\" …",
    "Moving {count} files to \"{destination}\" …" : "Moviendo{count} archivos a \"{destination}\" …",
    "Copying \"{source}\" to \"{destination}\" …" : "Copiando \"{source}\" a \"{destination}\" …",
    "Copying {count} files to \"{destination}\" …" : "Copiando {count} archivos a \"{destination}\" …",
    "Choose destination" : "Elegir destino",
    "Copy to {target}" : "Copiar a {target}",
    "Move to {target}" : "Mover a {target}",
    "Move or copy operation failed" : "La operación de mover o copiar falló",
    "Open folder" : "Abrir carpeta",
    "Open folder {displayName}" : "Abrir carpeta {displayName}",
    "Open in Files" : "Abrir en Archivos",
    "Open locally" : "Abrir localmente",
    "Failed to redirect to client" : "Fallo al redirigir al cliente",
    "Open file locally" : "Abrir archivo localmente",
    "The file should now open on your device. If it doesn't, please check that you have the desktop app installed." : "El archivo se abrirá ahora en su dispositivo. Si esto no ocurre, por favor verifique que ha instalado la aplicación de escritorio.",
    "Retry and close" : "Reintentar y cerrar",
    "Open online" : "Abrir en línea",
    "Details" : "Detalles",
    "Open the details sidebar" : "Abrir los detalles en el lateral",
    "Unfavorite" : "Quitar favorito",
    "View in folder" : "Ver en carpeta",
    "Type" : "Tipo",
    "Created new folder \"{name}\"" : "Se ha creado la carpeta nueva \"{name}\"",
    "Unable to initialize the templates directory" : "No se ha podido iniciar la carpeta de plantillas",
    "Create templates folder" : "Crear carpeta de plantillas",
    "Templates" : "Plantillas",
    "New template folder" : "Nueva carpeta de plantillas",
    "In folder" : "En carpeta",
    "Pick folder to search in" : "Selecciona la carpeta en la que buscar",
    "Search in all files" : "Buscar en todos los archivos",
    "Search in folder: {folder}" : "Buscar en carpeta: {folder}",
    "One of the dropped files could not be processed" : "Uno de los archivos arrastrados no puede ser procesado",
    "Your browser does not support the Filesystem API. Directories will not be uploaded" : "Su navegador no soporta la API de Sistema de archivos. Los directorios no se subirán",
    "No files to upload" : "Ningún archivo para subir",
    "Unable to create the directory {directory}" : "No se pudo crear el directorio {directory}",
    "Some files could not be uploaded" : "No se pudieron subir algunos archivos",
    "Files uploaded successfully" : "Se subieron los archivos exitosamente",
    "No files to process" : "No hay archivos para procesar",
    "Files copied successfully" : "Archivos copiados exitosamente",
    "Files moved successfully" : "Archivos movidos exitosamente",
    "Some files could not be copied" : "Algunos archivos no se han podido copiar",
    "Some files could not be moved" : "No se han podido mover algunos archivos",
    "Conflicts resolution skipped" : "Resolución de conflictos omitida",
    "Upload cancelled" : "Subida cancelada",
    "Could not rename \"{oldName}\", it does not exist any more" : "No se ha podido renombrar \"{oldName}\", ya no existe",
    "The name \"{newName}\" is already used in the folder \"{dir}\". Please choose a different name." : "El nombre \"{newName}\" ya está en uso en la carpeta \"{dir}\". Por favor, escoja un nombre diferente.",
    "Could not rename \"{oldName}\"" : "No se ha podido renombrar \"{oldName}\"",
    "This operation is forbidden" : "Esta operación está prohibida",
    "This folder is unavailable, please try again later or contact the administration" : "Esta carpeta no está disponible, por favor, intente de nuevo más tarde o contacte a la administración",
    "Storage is temporarily not available" : "El almacenamiento no está disponible temporalmente",
    "Unexpected error: {error}" : "Error inesperado: {error}",
    "_%n file_::_%n files_" : ["%n archivo","%n archivos","%n archivos"],
    "_%n folder_::_%n folders_" : ["%n carpeta","%n carpetas","%n carpetas"],
    "_%n hidden_::_%n hidden_" : ["%n oculto","%n ocultos","%n ocultos"],
    "Filename must not be empty." : "El nombre de archivo no debe estar vacío.",
    "\"{char}\" is not allowed inside a filename." : "\"{char}\" no está permitido en el nombre de archivo.",
    "\"{segment}\" is a reserved name and not allowed for filenames." : "\"{segment}\" es un nombre reservado y no se permite para los nombres de archivo.",
    "\"{extension}\" is not an allowed filetype." : "\"{extension}\" no es un tipo de archivo permitido.",
    "Filenames must not end with \"{extension}\"." : "Los nombres de archivo no puede terminar con \"{extension}\".",
    "List of favorite files and folders." : "Lista de archivos y carpetas favoritos.",
    "No favorites yet" : "Aún no hay favoritos",
    "Files and folders you mark as favorite will show up here" : "Aquí aparecerán los archivos y carpetas que has marcado como favoritos",
    "List of your files and folders." : "Lista de sus archivos y carpetas.",
    "Folder tree" : "Árbol de carpetas",
    "List of your files and folders that are not shared." : "Lista de sus archivos y carpetas que no están compartidos.",
    "No personal files found" : "No se encontraron archivos personales",
    "Files that are not shared will show up here." : "Los archivos y carpetas que no ha compartido aparecerán aquí.",
    "Recent" : "Reciente",
    "List of recently modified files and folders." : "Lista de archivos y carpetas modificados recientemente.",
    "No recently modified files" : "No hay archivos modificados recientemente.",
    "Files and folders you recently modified will show up here." : "Los archivos y carpetas que ha modificado recientemente aparecerán aquí.",
    "Search" : "Buscar",
    "Search results within your files." : "Resultados de búsqueda dentro de sus archivos.",
    "No entries found in this folder" : "No hay entradas en esta carpeta",
    "Select all" : "Seleccionar todo",
    "Upload too large" : "Subida demasido grande",
    "The files you are trying to upload exceed the maximum size for file uploads on this server." : "Los archivos que estás intentando subir sobrepasan el tamaño máximo permitido en este servidor.",
    "%1$s (renamed)" : "%1$s (renombrado)",
    "renamed file" : "archivo renombrado",
    "Upload (max. %s)" : "Subida (máx. %s)",
    "After enabling the windows compatible filenames, existing files cannot be modified anymore but can be renamed to valid new names by their owner." : "Una vez habilitados los nombres de archivo compatibles con Windows, los archivos existentes ya no se podrán modificar, pero su propietario podrá renombrarlos a otros nombres válidos de archivo.",
    "It is also possible to migrate files automatically after enabling this setting, please refer to the documentation about the occ command." : "También es posible migrar los archivos automáticamente luego de habilitar este ajuste. Por favor, refiérase a la documentación sobre el comando occ.",
    "Renamed \"{oldName}\" to \"{newName}\"" : "Renombrado \"{oldName}\" a \"{newName}\"",
    "Clear filter" : "Borrar filtro",
    "\"{displayName}\" failed on some elements" : "\"{displayName}\" falló en algunos elementos",
    "\"{displayName}\" batch action executed successfully" : "la acción en lotes \"{displayName}\" se ejecutó exitosamente",
    "\"{displayName}\" action failed" : "la acción \"{displayName}\" falló",
    "Submitting fields …" : "Enviando campos …",
    "Shared by link" : "Compartido por enlace",
    "Shared" : "Compartido",
    "\"{displayName}\" action executed successfully" : "la acción \"{displayName}\" se ejecutó exitosamente",
    "Filter file names …" : "Filtrar nombres de archivo …",
    "Clipboard is not available" : "El portapapeles no está disponible",
    "WebDAV URL copied to clipboard" : "URL de WebDAV copiado al portapapeles",
    "Enable the grid view" : "Habilitar vista de cuadrícula",
    "Enable folder tree" : "Habilitar el árbol de carpetas",
    "WebDAV" : "WebDAV",
    "Copy to clipboard" : "Copiar al portapapeles",
    "Use this address to access your Files via WebDAV" : "Use esta dirección para acceder a sus archivos vía WebDAV",
    "If you have enabled 2FA, you must create and use a new app password by clicking here." : "Si ha habilitado 2FA, debe crear y utilizar una nueva contraseña de aplicación haciendo clic aquí.",
    "Prevent warning dialogs from open or reenable them." : "Evitar que se abran los diálogos de advertencia o volver a habilitarlos.",
    "Show a warning dialog when changing a file extension." : "Mostrar un diálogo de advertencia cuando se cambia la extensión de un archivo.",
    "Keyboard shortcuts" : "Atajos de teclado",
    "Speed up your Files experience with these quick shortcuts." : "Acelere su experiencia con Archivos con estos rápidos atajos de teclado.",
    "Open the actions menu for a file" : "Abrir el menú de acciones para un archivo",
    "Rename a file" : "Renombrar un archivo",
    "Delete a file" : "Eliminar un archivo",
    "Favorite or remove a file from favorites" : "Marcar o desmarcar un archivo desde los favoritos",
    "Manage tags for a file" : "Gestionar etiquetas para un archivo",
    "Deselect all files" : "Deseleccionar todos los archivos",
    "Select or deselect a file" : "Seleccionar o deseleccionar un archivo",
    "Select a range of files" : "Seleccionar un rango de archivos",
    "Navigate to the parent folder" : "Navegar a la carpeta superior",
    "Navigate to the file above" : "Navegar al archivo anterior",
    "Navigate to the file below" : "Navegar al archivo siguiente",
    "Navigate to the file on the left (in grid mode)" : "Navegar al archivo de la izquierda (en modo cuadrícula)",
    "Navigate to the file on the right (in grid mode)" : "Navegar al archivo de la derecha (en modo cuadrícula)",
    "Toggle the grid view" : "Alternar vista en cuadrícula",
    "Open the sidebar for a file" : "Abrir la barra lateral para un archivo",
    "You" : "Tú",
    "Shared multiple times with different people" : "Compartido múltiples veces con diferentes personas",
    "Unable to change the favorite state of the file" : "No fue posible cambiar el estado de favorito del archivo",
    "Error while loading the file data" : "Error al cargar los datos del archivo",
    "Tags" : "Etiquetas",
    "Save as …" : "Guardar como …",
    "Converting files …" : "Convirtiendo archivos …",
    "Converting file …" : "Convirtiendo archivo …",
    "Deletion cancelled" : "Eliminación cancelada",
    "Edit locally" : "Editar localmente",
    "Moving \"{source}\" to \"{destination}\" …" : "Moviendo \"{source}\" a \"{destination}\" …",
    "Copying \"{source}\" to \"{destination}\" …" : "Copiando \"{source}\" a \"{destination}\" …",
    "(copy)" : "(copiar)",
    "(copy %n)" : "(copiar %n)",
    "Move cancelled" : "Se canceló la movida",
    "Cancelled move or copy of \"{filename}\"." : "Se canceló la operación de mover o copiar de \"{filename}\".",
    "Cancelled move or copy operation" : "Se canceló la operación de mover o copiar",
    "Open details" : "Abrir detalles",
    "Photos and images" : "Fotos e imágenes",
    "New folder creation cancelled" : "Se canceló la creación de la carpeta nueva",
    "This directory is unavailable, please check the logs or contact the administrator" : "Esta carpeta no está disponible, por favor verifique los registros o contacte con el administrador",
    "All folders" : "Todas las carpetas",
    "Open file sidebar" : "Abrir la barra lateral de archivo",
    "Search everywhere …" : "Buscar en todas partes …",
    "Search here …" : "Buscar aquí …",
    "Preparing …" : "Preparando …"
},
"nplurals=3; plural=n == 1 ? 0 : n != 0 && n % 1000000 == 0 ? 1 : 2;");
